Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Parse ¶
Parse uses provided output specifications to extract output values from the provided raw stdout string
**Parameters:**
specs: the specs for the outputs to be extracted inStr: the raw stdout string from the step whose outputs will be extracted
**Returns:**
map[string]string: the output keys and values error: an error if there is a problem
Types ¶
type Filter ¶
Filter can be used to extract an output value from the provided string using Apply(...)
type JSONFilter ¶
type JSONFilter struct {
Path string `yaml:"json_path"`
}
JSONFilter will parse a JSON string and extract the value at the provided path (like jq)
Click to show internal directories.
Click to hide internal directories.